@@ -2,7 +2,7 @@
 ;;
 ;;; Code:
 
-(put 'mime-display 'custom-loads '("mm-decode"))
+(put 'mime-display 'custom-loads '("mm-decode" "mm-view"))
 (put 'spam-stat 'custom-loads '("spam-stat"))
 (put 'bbdb-mua-specific-gnus 'custom-loads '("gnus-bbdb"))
 (put 'nnmail 'custom-loads '("nnmail"))
@@ -29,7 +29,6 @@
 (put 'gnus-score-files 'custom-loads '("gnus-score" "gnus"))
 (put 'gnus-agent 'custom-loads '("gnus-agent" "gnus-draft" "gnus"))
 (put 'message-news 'custom-loads '("message"))
-(put 'smime 'custom-loads '("smime"))
 (put 'gnus-xmas 'custom-loads '("gnus-xmas"))
 (put 'namazu 'custom-loads '("gnus-namazu"))
 (put 'gnus-summary-pick 'custom-loads '("gnus-salt"))
@@ -37,11 +36,11 @@
 (put 'languages 'custom-loads '("sieve"))
 (put 'spam 'custom-loads '("spam"))
 (put 'nnmail-various 'custom-loads '("nnmail"))
-(put 'extensions 'custom-loads '("sha1-el"))
+(put 'extensions 'custom-loads '("compface"))
 (put 'message-various 'custom-loads '("message"))
 (put 'gnus-summary-exit 'custom-loads '("gnus-sum" "gnus"))
 (put 'news 'custom-loads '("gnus-offline" "gnus" "message" "mm-decode"))
-(put 'gnus 'custom-loads '("gnus-art" "gnus-async" "gnus-delay" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-namazu" "gnus-offline" "gnus" "gnus-sieve" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "mail-source" "mm-url" "nnimap" "nnmail" "nnshimbun" "spam-stat"))
+(put 'gnus 'custom-loads '("gnus-art" "gnus-async" "gnus-delay" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-namazu" "gnus-offline" "gnus" "gnus-sieve" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "mail-source" "mm-url" "nnimap" "nnmail" "spam-stat"))
 (put 'spam-bogofilter 'custom-loads '("spam"))
 (put 'gnus-server 'custom-loads '("gnus-srvr" "gnus" "nnheader"))
 (put 'multimedia 'custom-loads '("gnus-audio" "mm-decode"))
@@ -60,6 +59,7 @@
 (put 'gnus-message 'custom-loads '("gnus-msg" "message" "gnus"))
 (put 'tls 'custom-loads '("tls"))
 (put 'starttls 'custom-loads '("starttls"))
+(put 'compface 'custom-loads '("compface"))
 (put 'gnus-summary-tree 'custom-loads '("gnus-salt"))
 (put 'gnus-score-default 'custom-loads '("gnus-score" "gnus-sum"))
 (put 'nnmail-duplicate 'custom-loads '("nnmail"))
@@ -75,11 +75,11 @@
 (put 'tools 'custom-loads '("sieve"))
 (put 'gnus-topic 'custom-loads '("gnus-topic"))
 (put 'gnus-summary-choose 'custom-loads '("gnus-sum"))
-(put 'sha1 'custom-loads '("sha1-el"))
 (put 'message-headers 'custom-loads '("message"))
 (put 'bbdb-mua-specific-gnus-scoring 'custom-loads '("gnus-bbdb"))
 (put 'message-forwarding 'custom-loads '("message"))
 (put 'message-faces 'custom-loads '("message"))
+(put 'password 'custom-loads '("password"))
 (put 'gnus-article-treat 'custom-loads '("gnus-art"))
 (put 'gnus-charset 'custom-loads '("gnus-group" "gnus-sum" "gnus"))
 (put 'comm 'custom-loads '("tls"))
@@ -102,6 +102,7 @@
 (put 'gnus-article-various 'custom-loads '("gnus-art" "gnus-sum"))
 (put 'imap 'custom-loads '("imap"))
 (put 'gnus-summary-marks 'custom-loads '("gnus-sum" "gnus"))
+(put 'spam-bsfilter 'custom-loads '("spam"))
 (put 'nnmail-expire 'custom-loads '("nnmail"))
 (put 'gnus-article-saving 'custom-loads '("gnus-art"))
 (put 'message-mail 'custom-loads '("message"))
@@ -110,7 +111,7 @@
 (put 'applications 'custom-loads '("canlock"))
 (put 'gnus-registry 'custom-loads '("gnus-registry"))
 (put 'gnus-start-server 'custom-loads '("gnus-start"))
-(put 'canlock 'custom-loads '("canlock-om" "canlock"))
+(put 'canlock 'custom-loads '("canlock"))
 (put 'gnus-extract-archive 'custom-loads '("gnus-uu"))
 (put 'message 'custom-loads '("message" "mml-sec" "mml"))
 (put 'message-sending 'custom-loads '("message"))
@@ -125,17 +126,18 @@
 (put 'gnus-server-visual 'custom-loads '("gnus-srvr"))
 (put 'gnus-asynchronous 'custom-loads '("gnus-async"))
 (put 'gnus-dribble-file 'custom-loads '("gnus-start"))
-(put 'nnshimbun 'custom-loads '("nnshimbun"))
 (put 'gnus-article-highlight 'custom-loads '("gnus-art"))
 (put 'gnus-cache 'custom-loads '("gnus-cache" "gnus"))
 (put 'gnus-picon 'custom-loads '("gnus-art" "gnus-picon"))
 (put 'gnus-extract 'custom-loads '("binhex" "gnus" "gnus-uu" "uudecode"))
 (put 'gnus-outlook-deuglify 'custom-loads '("deuglify"))
 (put 'gnus-article 'custom-loads '("gnus-art" "gnus-cite"))
+(put 'spam-spamassassin 'custom-loads '("spam"))
 (put 'nnimap 'custom-loads '("nnimap"))
 (put 'spam-report 'custom-loads '("spam-report"))
 (put 'nnir 'custom-loads '("nnir"))
 (put 'gnus-group-foreign 'custom-loads '("gnus-group" "gnus-msg"))
+(put 'netrc 'custom-loads '("netrc"))
 (put 'gnus-offline 'custom-loads '("gnus-offline"))
 (put 'spam-ifile 'custom-loads '("spam"))
 (put 'mailcap 'custom-loads '("gnus-mailcap"))
@@ -290,8 +292,8 @@
 
 
 ;;;### (autoloads (binhex-decode-region binhex-decode-region-external
-;;;;;;  binhex-decode-region-internal) "binhex" "binhex.el" (16049
-;;;;;;  55520))
+;;;;;;  binhex-decode-region-internal) "binhex" "binhex.el" (16532
+;;;;;;  16366))
 ;;; Generated autoloads from binhex.el
 
 (defconst binhex-begin-line "^:...............................................................$")
@@ -309,7 +311,7 @@ Binhex decode region between START and END." t nil)
 ;;;***
 
 ;;;### (autoloads (canlock-verify canlock-insert-header) "canlock"
-;;;;;;  "canlock.el" (16376 42740))
+;;;;;;  "canlock.el" (16532 16368))
 ;;; Generated autoloads from canlock.el
 
 (autoload (quote canlock-insert-header) "canlock" "\
@@ -318,9 +320,7 @@ Insert a Cancel-Key and/or a Cancel-Lock header if possible." nil nil)
 (autoload (quote canlock-verify) "canlock" "\
 Verify Cancel-Lock or Cancel-Key in BUFFER.
 If BUFFER is nil, the current buffer is assumed.  Signal an error if
-it fails.  You can modify the behavior of this function to return non-
-nil instead of to signal an error by setting the option
-`canlock-ignore-errors' to non-nil." t nil)
+it fails." t nil)
 
 ;;;***
 
@@ -328,7 +328,7 @@ nil instead of to signal an error by setting the option
 ;;;;;;  gnus-article-outlook-repair-attribution gnus-article-outlook-unwrap-lines
 ;;;;;;  gnus-outlook-display-hook gnus-outlook-deuglify-unwrap-max
 ;;;;;;  gnus-outlook-deuglify-unwrap-min) "deuglify" "deuglify.el"
-;;;;;;  (16376 42740))
+;;;;;;  (16532 16368))
 ;;; Generated autoloads from deuglify.el
 
 (defvar gnus-outlook-deuglify-unwrap-min 45 "\
@@ -372,7 +372,7 @@ Play sounds in message buffers." t nil)
 ;;;***
 
 ;;;### (autoloads (fill-flowed fill-flowed-encode) "flow-fill" "flow-fill.el"
-;;;;;;  (16376 42741))
+;;;;;;  (16532 16369))
 ;;; Generated autoloads from flow-fill.el
 
 (autoload (quote fill-flowed-encode) "flow-fill" nil nil nil)
@@ -382,7 +382,7 @@ Play sounds in message buffers." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus gnus-other-frame gnus-slave gnus-no-server
-;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (16376 42762))
+;;;;;;  gnus-slave-no-server) "gnus" "gnus.el" (16532 16394))
 ;;; Generated autoloads from gnus.el
 
 (autoload (quote gnus-slave-no-server) "gnus" "\
@@ -419,9 +419,9 @@ prompt the user for the name of an NNTP server to use." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-agent-regenerate gnus-agent-batch gnus-agent-batch-fetch
-;;;;;;  gnus-agent-possibly-save-gcc gnus-agentize gnus-slave-unplugged
-;;;;;;  gnus-plugged gnus-unplugged) "gnus-agent" "gnus-agent.el"
-;;;;;;  (16376 42741))
+;;;;;;  gnus-agent-delete-group gnus-agent-rename-group gnus-agent-possibly-save-gcc
+;;;;;;  gnus-agentize gnus-slave-unplugged gnus-plugged gnus-unplugged)
+;;;;;;  "gnus-agent" "gnus-agent.el" (16532 16369))
 ;;; Generated autoloads from gnus-agent.el
 
 (autoload (quote gnus-unplugged) "gnus-agent" "\
@@ -447,6 +447,16 @@ minor mode in all Gnus buffers." t nil)
 (autoload (quote gnus-agent-possibly-save-gcc) "gnus-agent" "\
 Save GCC if Gnus is unplugged." nil nil)
 
+(autoload (quote gnus-agent-rename-group) "gnus-agent" "\
+Rename fully-qualified OLD-GROUP as NEW-GROUP.  Always updates the agent, even when
+disabled, as the old agent files would corrupt gnus when the agent was
+next enabled. Depends upon the caller to determine whether group renaming is supported." nil nil)
+
+(autoload (quote gnus-agent-delete-group) "gnus-agent" "\
+Delete fully-qualified GROUP.  Always updates the agent, even when
+disabled, as the old agent files would corrupt gnus when the agent was
+next enabled. Depends upon the caller to determine whether group deletion is supported." nil nil)
+
 (autoload (quote gnus-agent-batch-fetch) "gnus-agent" "\
 Start Gnus and fetch session." t nil)
 
@@ -460,7 +470,7 @@ If CLEAN, obsolete (ignore)." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-article-prepare-display) "gnus-art" "gnus-art.el"
-;;;;;;  (16376 42744))
+;;;;;;  (16532 16370))
 ;;; Generated autoloads from gnus-art.el
 
 (autoload (quote gnus-article-prepare-display) "gnus-art" "\
@@ -534,8 +544,9 @@ Call this function to hook BBDB into message-mode." nil nil)
 
 ;;;***
 
-;;;### (autoloads (gnus-cache-generate-nov-databases gnus-cache-generate-active
-;;;;;;  gnus-jog-cache) "gnus-cache" "gnus-cache.el" (16376 42749))
+;;;### (autoloads (gnus-cache-delete-group gnus-cache-rename-group
+;;;;;;  gnus-cache-generate-nov-databases gnus-cache-generate-active
+;;;;;;  gnus-jog-cache) "gnus-cache" "gnus-cache.el" (16532 16374))
 ;;; Generated autoloads from gnus-cache.el
 
 (autoload (quote gnus-jog-cache) "gnus-cache" "\
@@ -550,28 +561,20 @@ Generate the cache active file." t nil)
 (autoload (quote gnus-cache-generate-nov-databases) "gnus-cache" "\
 Generate NOV files recursively starting in DIR." t nil)
 
-;;;***
-
-;;;### (autoloads (find-cl-run-time-functions) "gnus-clfns" "gnus-clfns.el"
-;;;;;;  (16049 55529))
-;;; Generated autoloads from gnus-clfns.el
+(autoload (quote gnus-cache-rename-group) "gnus-cache" "\
+Rename OLD-GROUP as NEW-GROUP.  Always updates the cache, even when
+disabled, as the old cache files would corrupt gnus when the cache was
+next enabled. Depends upon the caller to determine whether group renaming is supported." nil nil)
 
-(autoload (quote find-cl-run-time-functions) "gnus-clfns" "\
-Find CL run-time functions in the FILE-OR-DIRECTORY.  You can alter
-the behavior of this command with the prefix ARG as described below.
-
-By default, it searches for all the CL run-time functions listed in
- the variable `cl-run-time-functions'.
-With 1 or 3 \\[universal-argument]'s, the built-in functions in this Emacs will not be
- reported.
-With 2 or 3 \\[universal-argument]'s, just the symbols will also be reported.
-
-You can use the `digit-argument' 1, 2 or 3 instead of \\[universal-argument]'s." t nil)
+(autoload (quote gnus-cache-delete-group) "gnus-cache" "\
+Delete GROUP.  Always updates the cache, even when
+disabled, as the old cache files would corrupt gnus when the cache was
+next enabled. Depends upon the caller to determine whether group deletion is supported." nil nil)
 
 ;;;***
 
 ;;;### (autoloads (gnus-delay-initialize gnus-delay-send-queue gnus-delay-article)
-;;;;;;  "gnus-delay" "gnus-delay.el" (16049 56069))
+;;;;;;  "gnus-delay" "gnus-delay.el" (16532 16375))
 ;;; Generated autoloads from gnus-delay.el
 
 (defgroup gnus-delay nil "Arrange for sending postings later." :group (quote gnus))
@@ -603,7 +606,7 @@ Checking delayed messages is skipped if optional arg NO-CHECK is non-nil." nil n
 ;;;***
 
 ;;;### (autoloads (turn-on-gnus-dired-mode) "gnus-dired" "gnus-dired.el"
-;;;;;;  (16376 42749))
+;;;;;;  (16532 16375))
 ;;; Generated autoloads from gnus-dired.el
 
 (autoload (quote turn-on-gnus-dired-mode) "gnus-dired" "\
@@ -612,7 +615,7 @@ Convenience method to turn on gnus-dired-mode." nil nil)
 ;;;***
 
 ;;;### (autoloads (gnus-draft-reminder) "gnus-draft" "gnus-draft.el"
-;;;;;;  (16376 42749))
+;;;;;;  (16532 16375))
 ;;; Generated autoloads from gnus-draft.el
 
 (autoload (quote gnus-draft-reminder) "gnus-draft" "\
@@ -622,7 +625,7 @@ Reminder user if there are unsent drafts." t nil)
 
 ;;;### (autoloads (gnus-convert-png-to-face gnus-convert-face-to-png
 ;;;;;;  gnus-face-from-file gnus-x-face-from-file gnus-insert-random-x-face-header
-;;;;;;  gnus-random-x-face) "gnus-fun" "gnus-fun.el" (16376 42750))
+;;;;;;  gnus-random-x-face) "gnus-fun" "gnus-fun.el" (16532 16375))
 ;;; Generated autoloads from gnus-fun.el
 
 (autoload (quote gnus-random-x-face) "gnus-fun" "\
@@ -649,7 +652,7 @@ FILE should be a PNG file that's 48x48 and smaller than or equal to
 ;;;***
 
 ;;;### (autoloads (gnus-fetch-group-other-frame gnus-fetch-group)
-;;;;;;  "gnus-group" "gnus-group.el" (16376 42750))
+;;;;;;  "gnus-group" "gnus-group.el" (16532 16376))
 ;;; Generated autoloads from gnus-group.el
 
 (autoload (quote gnus-fetch-group) "gnus-group" "\
@@ -661,8 +664,8 @@ Pop up a frame and enter GROUP." t nil)
 
 ;;;***
 
-;;;### (autoloads (gnus-batch-score) "gnus-kill" "gnus-kill.el" (16049
-;;;;;;  55532))
+;;;### (autoloads (gnus-batch-score) "gnus-kill" "gnus-kill.el" (16532
+;;;;;;  16376))
 ;;; Generated autoloads from gnus-kill.el
 
 (defalias (quote gnus-batch-kill) (quote gnus-batch-score))
@@ -674,8 +677,8 @@ Usage: emacs -batch -l ~/.emacs -l gnus -f gnus-batch-score" t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-mailing-list-mode gnus-mailing-list-insinuate
-;;;;;;  turn-on-gnus-mailing-list-mode) "gnus-ml" "gnus-ml.el" (16049
-;;;;;;  55534))
+;;;;;;  turn-on-gnus-mailing-list-mode) "gnus-ml" "gnus-ml.el" (16532
+;;;;;;  16376))
 ;;; Generated autoloads from gnus-ml.el
 
 (autoload (quote turn-on-gnus-mailing-list-mode) "gnus-ml" nil nil nil)
@@ -692,26 +695,26 @@ Minor mode for providing mailing-list commands.
 ;;;***
 
 ;;;### (autoloads (gnus-group-split-fancy gnus-group-split gnus-group-split-update
-;;;;;;  gnus-group-split-setup) "gnus-mlspl" "gnus-mlspl.el" (16049
-;;;;;;  55534))
+;;;;;;  gnus-group-split-setup) "gnus-mlspl" "gnus-mlspl.el" (16532
+;;;;;;  16376))
 ;;; Generated autoloads from gnus-mlspl.el
 
 (autoload (quote gnus-group-split-setup) "gnus-mlspl" "\
-Set up the split for nnmail-split-fancy.
+Set up the split for `nnmail-split-fancy'.
 Sets things up so that nnmail-split-fancy is used for mail
 splitting, and defines the variable nnmail-split-fancy according with
 group parameters.
 
 If AUTO-UPDATE is non-nil (prefix argument accepted, if called
 interactively), it makes sure nnmail-split-fancy is re-computed before
-getting new mail, by adding gnus-group-split-update to
-nnmail-pre-get-new-mail-hook.
+getting new mail, by adding `gnus-group-split-update' to
+`nnmail-pre-get-new-mail-hook'.
 
 A non-nil CATCH-ALL replaces the current value of
-gnus-group-split-default-catch-all-group.  This variable is only used
+`gnus-group-split-default-catch-all-group'.  This variable is only used
 by gnus-group-split-update, and only when its CATCH-ALL argument is
 nil.  This argument may contain any fancy split, that will be added as
-the last split in a `|' split produced by gnus-group-split-fancy,
+the last split in a `|' split produced by `gnus-group-split-fancy',
 unless overridden by any group marked as a catch-all group.  Typical
 uses are as simple as the name of a default mail group, but more
 elaborate fancy splits may also be useful to split mail that doesn't
@@ -719,17 +722,17 @@ match any of the group-specified splitting rules.  See
 `gnus-group-split-fancy' for details." t nil)
 
 (autoload (quote gnus-group-split-update) "gnus-mlspl" "\
-Computes nnmail-split-fancy from group params and CATCH-ALL, by
+Computes `nnmail-split-fancy' from group params and CATCH-ALL, by
 calling (gnus-group-split-fancy nil nil CATCH-ALL).
 
-If CATCH-ALL is nil, gnus-group-split-default-catch-all-group is used
-instead.  This variable is set by gnus-group-split-setup." t nil)
+If CATCH-ALL is nil, `gnus-group-split-default-catch-all-group' is used
+instead.  This variable is set by `gnus-group-split-setup'." t nil)
 
 (autoload (quote gnus-group-split) "gnus-mlspl" "\
-Uses information from group parameters in order to split mail.
+Use information from group parameters in order to split mail.
 See `gnus-group-split-fancy' for more information.
 
-gnus-group-split is a valid value for nnmail-split-methods." nil nil)
+`gnus-group-split' is a valid value for `nnmail-split-methods'." nil nil)
 
 (autoload (quote gnus-group-split-fancy) "gnus-mlspl" "\
 Uses information from group parameters in order to split mail.
@@ -785,7 +788,7 @@ Calling (gnus-group-split-fancy nil nil \"mail.others\") returns:
 ;;;***
 
 ;;;### (autoloads (gnus-change-server) "gnus-move" "gnus-move.el"
-;;;;;;  (15066 10799))
+;;;;;;  (16532 16376))
 ;;; Generated autoloads from gnus-move.el
 
 (autoload (quote gnus-change-server) "gnus-move" "\
@@ -795,7 +798,7 @@ Update the .newsrc.eld file to reflect the change of nntp server." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-button-reply gnus-button-mailto gnus-msg-mail)
-;;;;;;  "gnus-msg" "gnus-msg.el" (16376 42751))
+;;;;;;  "gnus-msg" "gnus-msg.el" (16532 16376))
 ;;; Generated autoloads from gnus-msg.el
 
 (autoload (quote gnus-msg-mail) "gnus-msg" "\
@@ -815,8 +818,8 @@ Like `message-reply'." t nil)
 
 ;;;### (autoloads (gnus-namazu-insinuate gnus-namazu-stop-update
 ;;;;;;  gnus-namazu-update-all-indices gnus-namazu-update-index gnus-namazu-create-index
-;;;;;;  gnus-namazu-search) "gnus-namazu" "gnus-namazu.el" (16376
-;;;;;;  42752))
+;;;;;;  gnus-namazu-search) "gnus-namazu" "gnus-namazu.el" (16532
+;;;;;;  16377))
 ;;; Generated autoloads from gnus-namazu.el
 
 (autoload (quote gnus-namazu-search) "gnus-namazu" "\
@@ -840,8 +843,8 @@ Stop the running indexer of Namazu." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-treat-newsgroups-picon gnus-treat-mail-picon
-;;;;;;  gnus-treat-from-picon) "gnus-picon" "gnus-picon.el" (16376
-;;;;;;  42753))
+;;;;;;  gnus-treat-from-picon) "gnus-picon" "gnus-picon.el" (16532
+;;;;;;  16378))
 ;;; Generated autoloads from gnus-picon.el
 
 (autoload (quote gnus-treat-from-picon) "gnus-picon" "\
@@ -859,9 +862,10 @@ If picons are already displayed, remove them." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-add-to-sorted-list gnus-sorted-nunion gnus-sorted-union
-;;;;;;  gnus-sorted-nintersection gnus-sorted-intersection gnus-intersection
-;;;;;;  gnus-sorted-complement gnus-sorted-ndifference gnus-sorted-difference)
-;;;;;;  "gnus-range" "gnus-range.el" (16049 55537))
+;;;;;;  gnus-sorted-nintersection gnus-sorted-range-intersection
+;;;;;;  gnus-sorted-intersection gnus-intersection gnus-sorted-complement
+;;;;;;  gnus-sorted-ndifference gnus-sorted-difference) "gnus-range"
+;;;;;;  "gnus-range.el" (16532 16379))
 ;;; Generated autoloads from gnus-range.el
 
 (autoload (quote gnus-sorted-difference) "gnus-range" "\
@@ -884,6 +888,10 @@ Both lists have to be sorted over <." nil nil)
 Return intersection of LIST1 and LIST2.
 LIST1 and LIST2 have to be sorted over <." nil nil)
 
+(autoload (quote gnus-sorted-range-intersection) "gnus-range" "\
+Return intersection of RANGE1 and RANGE2.
+RANGE1 and RANGE2 have to be sorted over <." nil nil)
+
 (defalias (quote gnus-set-sorted-intersection) (quote gnus-sorted-nintersection))
 
 (autoload (quote gnus-sorted-nintersection) "gnus-range" "\
@@ -904,7 +912,7 @@ Add NUM into sorted LIST by side effect." nil nil)
 ;;;***
 
 ;;;### (autoloads (gnus-registry-install-hooks gnus-registry-initialize)
-;;;;;;  "gnus-registry" "gnus-registry.el" (16376 42753))
+;;;;;;  "gnus-registry" "gnus-registry.el" (16532 16379))
 ;;; Generated autoloads from gnus-registry.el
 
 (autoload (quote gnus-registry-initialize) "gnus-registry" nil t nil)
@@ -936,7 +944,7 @@ See the documentation for these variables and functions for details." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-batch-brew-soup) "gnus-soup" "gnus-soup.el"
-;;;;;;  (16376 42754))
+;;;;;;  (16532 16380))
 ;;; Generated autoloads from gnus-soup.el
 
 (autoload (quote gnus-batch-brew-soup) "gnus-soup" "\
@@ -954,7 +962,7 @@ Note -- this function hasn't been implemented yet." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-update-format) "gnus-spec" "gnus-spec.el"
-;;;;;;  (16049 55539))
+;;;;;;  (16532 16380))
 ;;; Generated autoloads from gnus-spec.el
 
 (autoload (quote gnus-update-format) "gnus-spec" "\
@@ -963,8 +971,8 @@ Update the format specification near point." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-fixup-nnimap-unread-after-getting-new-news
-;;;;;;  gnus-declare-backend) "gnus-start" "gnus-start.el" (16376
-;;;;;;  42754))
+;;;;;;  gnus-declare-backend) "gnus-start" "gnus-start.el" (16532
+;;;;;;  16381))
 ;;; Generated autoloads from gnus-start.el
 
 (autoload (quote gnus-declare-backend) "gnus-start" "\
@@ -983,7 +991,7 @@ Add the window configuration CONF to `gnus-buffer-configuration'." nil nil)
 
 ;;;***
 
-;;;### (autoloads (html2text) "html2text" "html2text.el" (16376 42763))
+;;;### (autoloads (html2text) "html2text" "html2text.el" (16532 16396))
 ;;; Generated autoloads from html2text.el
 
 (autoload (quote html2text) "html2text" "\
@@ -1007,8 +1015,8 @@ Convert HTML to plain text in the current buffer." t nil)
 ;;;;;;  message-signature-separator message-from-style message-cross-post-note-function
 ;;;;;;  message-followup-to-note message-cross-post-note message-cross-post-default
 ;;;;;;  message-archive-note message-archive-header message-mark-insert-end
-;;;;;;  message-mark-insert-begin) "message" "message.el" (16376
-;;;;;;  42764))
+;;;;;;  message-mark-insert-begin) "message" "message.el" (16532
+;;;;;;  16397))
 ;;; Generated autoloads from message.el
 
 (defvar message-mark-insert-begin "--8<---------------cut here---------------start------------->8---\n" "\
@@ -1296,7 +1304,7 @@ If NO-DISPLAY is nil, display it. Otherwise, do nothing after replacing." nil ni
 ;;;***
 
 ;;;### (autoloads (mm-url-insert-file-contents-external mm-url-insert-file-contents)
-;;;;;;  "mm-url" "mm-url.el" (16376 42767))
+;;;;;;  "mm-url" "mm-url.el" (16532 16403))
 ;;; Generated autoloads from mm-url.el
 
 (autoload (quote mm-url-insert-file-contents) "mm-url" "\
@@ -1328,7 +1336,7 @@ Dissect the current buffer and return a list of uu handles." nil nil)
 
 ;;;### (autoloads (mml2015-self-encrypt mml2015-sign mml2015-encrypt
 ;;;;;;  mml2015-verify-test mml2015-verify mml2015-decrypt-test mml2015-decrypt)
-;;;;;;  "mml2015" "mml2015.el" (16376 42769))
+;;;;;;  "mml2015" "mml2015.el" (16532 16406))
 ;;; Generated autoloads from mml2015.el
 
 (autoload (quote mml2015-decrypt) "mml2015" nil nil nil)
@@ -1348,7 +1356,7 @@ Dissect the current buffer and return a list of uu handles." nil nil)
 ;;;***
 
 ;;;### (autoloads (nndiary-generate-nov-databases) "nndiary" "nndiary.el"
-;;;;;;  (16376 42771))
+;;;;;;  (16532 16407))
 ;;; Generated autoloads from nndiary.el
 
 (autoload (quote nndiary-generate-nov-databases) "nndiary" "\
@@ -1356,7 +1364,7 @@ Generate NOV databases in all nndiary directories." t nil)
 
 ;;;***
 
-;;;### (autoloads (nndoc-add-type) "nndoc" "nndoc.el" (16376 42772))
+;;;### (autoloads (nndoc-add-type) "nndoc" "nndoc.el" (16532 16407))
 ;;; Generated autoloads from nndoc.el
 
 (autoload (quote nndoc-add-type) "nndoc" "\
@@ -1369,7 +1377,7 @@ symbol in the alist." nil nil)
 ;;;***
 
 ;;;### (autoloads (nnfolder-generate-active-file) "nnfolder" "nnfolder.el"
-;;;;;;  (16376 42772))
+;;;;;;  (16532 16408))
 ;;; Generated autoloads from nnfolder.el
 
 (autoload (quote nnfolder-generate-active-file) "nnfolder" "\
@@ -1379,7 +1387,7 @@ This command does not work if you use short group names." t nil)
 ;;;***
 
 ;;;### (autoloads (nnkiboze-generate-groups) "nnkiboze" "nnkiboze.el"
-;;;;;;  (16049 55554))
+;;;;;;  (16532 16411))
 ;;; Generated autoloads from nnkiboze.el
 
 (autoload (quote nnkiboze-generate-groups) "nnkiboze" "\
@@ -1389,21 +1397,12 @@ Finds out what articles are to be part of the nnkiboze groups." t nil)
 ;;;***
 
 ;;;### (autoloads (nnml-generate-nov-databases) "nnml" "nnml.el"
-;;;;;;  (16376 42774))
+;;;;;;  (16532 16413))
 ;;; Generated autoloads from nnml.el
 
 (autoload (quote nnml-generate-nov-databases) "nnml" "\
 Generate NOV databases in all nnml directories." t nil)
 
-;;;***
-
-;;;### (autoloads (gnus-group-make-shimbun-group) "nnshimbun" "nnshimbun.el"
-;;;;;;  (16049 55559))
-;;; Generated autoloads from nnshimbun.el
-
-(autoload (quote gnus-group-make-shimbun-group) "nnshimbun" "\
-Create a nnshimbun group." t nil)
-
 ;;;***
 
 ;;;### (autoloads (nnsoup-revert-variables nnsoup-set-variables nnsoup-pack-replies)
@@ -1440,7 +1439,7 @@ them into characters should be done separately." t nil)
 ;;;***
 
 ;;;### (autoloads (gnus-score-mode) "score-mode" "score-mode.el"
-;;;;;;  (16049 55565))
+;;;;;;  (16532 16420))
 ;;; Generated autoloads from score-mode.el
 
 (autoload (quote gnus-score-mode) "score-mode" "\
@@ -1449,21 +1448,10 @@ This mode is an extended emacs-lisp mode.
 
 \\{gnus-score-mode-map}" t nil)
 
-;;;***
-
-;;;### (autoloads (sha1) "sha1-el" "sha1-el.el" (16376 42775))
-;;; Generated autoloads from sha1-el.el
-
-(autoload (quote sha1) "sha1-el" "\
-Return the SHA1 (Secure Hash Algorithm) of an object.
-OBJECT is either a string or a buffer.
-Optional arguments BEG and END denote buffer positions for computing the
-hash of a portion of OBJECT." nil nil)
-
 ;;;***
 
 ;;;### (autoloads (sieve-upload-and-bury sieve-upload sieve-manage)
-;;;;;;  "sieve" "sieve.el" (16376 42775))
+;;;;;;  "sieve" "sieve.el" (16532 16421))
 ;;; Generated autoloads from sieve.el
 
 (autoload (quote sieve-manage) "sieve" nil t nil)
@@ -1474,8 +1462,8 @@ hash of a portion of OBJECT." nil nil)
 
 ;;;***
 
-;;;### (autoloads (sieve-mode) "sieve-mode" "sieve-mode.el" (16049
-;;;;;;  56074))
+;;;### (autoloads (sieve-mode) "sieve-mode" "sieve-mode.el" (16532
+;;;;;;  16421))
 ;;; Generated autoloads from sieve-mode.el
 
 (autoload (quote sieve-mode) "sieve-mode" "\
@@ -1498,11 +1486,49 @@ Turning on Sieve mode runs `sieve-mode-hook'." t nil)
 
 ;;;***
 
-;;;### (autoloads (spam-initialize) "spam" "spam.el" (16376 42776))
+;;;### (autoloads (spam-initialize) "spam" "spam.el" (16532 16422))
 ;;; Generated autoloads from spam.el
 
 (autoload (quote spam-initialize) "spam" "\
-Install the spam.el hooks and do other initialization" t nil)
+Install the spam.el hooks and do other initialization.
+When SYMBOLS is given, set those variables to t.  This is so you
+can call spam-initialize before you set spam-use-* variables on
+explicitly, and matters only if you need the extra headers
+installed through spam-necessary-extra-headers." t nil)
+
+;;;***
+
+;;;### (autoloads (spam-report-deagentize spam-report-agentize spam-report-url-to-file
+;;;;;;  spam-report-url-ping-mm-url spam-report-process-queue) "spam-report"
+;;;;;;  "spam-report.el" (16532 16422))
+;;; Generated autoloads from spam-report.el
+
+(autoload (quote spam-report-process-queue) "spam-report" "\
+Report all queued requests from `spam-report-requests-file'.
+
+If FILE is given, use it instead of `spam-report-requests-file'.
+If KEEP is t, leave old requests in the file.  If KEEP is the
+symbol `ask', query before flushing the queue file." t nil)
+
+(autoload (quote spam-report-url-ping-mm-url) "spam-report" "\
+Ping a host through HTTP, addressing a specific GET resource. Use
+the external program specified in `mm-url-program' to connect to
+server." nil nil)
+
+(autoload (quote spam-report-url-to-file) "spam-report" "\
+Collect spam report requests in `spam-report-requests-file'.
+Customize `spam-report-url-ping-function' to use this function." nil nil)
+
+(autoload (quote spam-report-agentize) "spam-report" "\
+Add spam-report support to the Agent.
+Spam reports will be queued with \\[spam-report-url-to-file] when
+the Agent is unplugged, and will be submitted in a batch when the
+Agent is plugged." t nil)
+
+(autoload (quote spam-report-deagentize) "spam-report" "\
+Remove spam-report support from the Agent.
+Spam reports will be queued with the method used when
+\\[spam-report-agentize] was run." t nil)
 
 ;;;***
 
@@ -1564,7 +1590,7 @@ If DATE is malformed, return a time value of zeros." nil nil)
 
 ;;;### (autoloads (uudecode-decode-region uudecode-decode-region-internal
 ;;;;;;  uudecode-decode-region-external) "uudecode" "uudecode.el"
-;;;;;;  (16049 55566))
+;;;;;;  (16532 16423))
 ;;; Generated autoloads from uudecode.el
 
 (autoload (quote uudecode-decode-region-external) "uudecode" "\
